#[non_exhaustive]pub struct ObjectMetadataReportOptions {
pub metadata_fields: Vec<String>,
pub filter: Option<Filter>,
pub destination_options: Option<DestinationOptions>,
/* private fields */
}Expand description
Report specification for exporting object metadata. Next ID: 4
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.metadata_fields: Vec<String>Metadata fields to be included in the report.
filter: Option<Filter>Filter options for storage systems.
destination_options: Option<DestinationOptions>Options on destination for storage systems.
Implementations
Sourceimpl ObjectMetadataReportOptions
impl ObjectMetadataReportOptions
Sourcepub fn set_metadata_fields<T, V>(self, v: T) -> Self
pub fn set_metadata_fields<T, V>(self, v: T) -> Self
Sets the value of metadata_fields.
Example
let x = ObjectMetadataReportOptions::new().set_metadata_fields(["a", "b", "c"]);Sourcepub fn set_filter<T: Into<Option<Filter>>>(self, v: T) -> Self
pub fn set_filter<T: Into<Option<Filter>>>(self, v: T) -> Self
Sets the value of filter.
Note that all the setters affecting filter are mutually
exclusive.
Example
use google_cloud_storageinsights_v1::model::CloudStorageFilters;
let x = ObjectMetadataReportOptions::new().set_filter(Some(
google_cloud_storageinsights_v1::model::object_metadata_report_options::Filter::StorageFilters(CloudStorageFilters::default().into())));Sourcepub fn storage_filters(&self) -> Option<&Box<CloudStorageFilters>>
pub fn storage_filters(&self) -> Option<&Box<CloudStorageFilters>>
The value of filter
if it holds a StorageFilters, None if the field is not set or
holds a different branch.
Sourcepub fn set_storage_filters<T: Into<Box<CloudStorageFilters>>>(
self,
v: T,
) -> Self
pub fn set_storage_filters<T: Into<Box<CloudStorageFilters>>>( self, v: T, ) -> Self
Sets the value of filter
to hold a StorageFilters.
Note that all the setters affecting filter are
mutually exclusive.
Example
use google_cloud_storageinsights_v1::model::CloudStorageFilters;
let x = ObjectMetadataReportOptions::new().set_storage_filters(CloudStorageFilters::default()/* use setters */);
assert!(x.storage_filters().is_some());Sourcepub fn set_destination_options<T: Into<Option<DestinationOptions>>>(
self,
v: T,
) -> Self
pub fn set_destination_options<T: Into<Option<DestinationOptions>>>( self, v: T, ) -> Self
Sets the value of destination_options.
Note that all the setters affecting destination_options are mutually
exclusive.
Example
use google_cloud_storageinsights_v1::model::CloudStorageDestinationOptions;
let x = ObjectMetadataReportOptions::new().set_destination_options(Some(
google_cloud_storageinsights_v1::model::object_metadata_report_options::DestinationOptions::StorageDestinationOptions(CloudStorageDestinationOptions::default().into())));Sourcepub fn storage_destination_options(
&self,
) -> Option<&Box<CloudStorageDestinationOptions>>
pub fn storage_destination_options( &self, ) -> Option<&Box<CloudStorageDestinationOptions>>
The value of destination_options
if it holds a StorageDestinationOptions, None if the field is not set or
holds a different branch.
Sourcepub fn set_storage_destination_options<T: Into<Box<CloudStorageDestinationOptions>>>(
self,
v: T,
) -> Self
pub fn set_storage_destination_options<T: Into<Box<CloudStorageDestinationOptions>>>( self, v: T, ) -> Self
Sets the value of destination_options
to hold a StorageDestinationOptions.
Note that all the setters affecting destination_options are
mutually exclusive.
Example
use google_cloud_storageinsights_v1::model::CloudStorageDestinationOptions;
let x = ObjectMetadataReportOptions::new().set_storage_destination_options(CloudStorageDestinationOptions::default()/* use setters */);
assert!(x.storage_destination_options().is_some());Trait Implementations
Sourceimpl Clone for ObjectMetadataReportOptions
impl Clone for ObjectMetadataReportOptions
Sourcefn clone(&self) -> ObjectMetadataReportOptions
fn clone(&self) -> ObjectMetadataReportOptions
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more