#[non_exhaustive]pub struct CreateDatasetConfigRequest {
pub parent: String,
pub dataset_config_id: String,
pub dataset_config: Option<DatasetConfig>,
pub request_id: String,
/* private fields */
}Expand description
Request message for
CreateDatasetConfig
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
dataset_config_id: StringRequired. ID of the requesting object.
If auto-generating ID is enabled on the server-side, remove this field and
dataset_config_id from the method_signature of Create RPC
Note: The value should not contain any hyphens.
dataset_config: Option<DatasetConfig>Required. The resource being created
request_id: StringOptional. A unique identifier for your request. Specify the request ID if you need to retry the request. If you retry the request with the same ID within 60 minutes, the server ignores the request if it has already completed the original request.
For example, if your initial request times out and you retry the request using the same request ID, the server recognizes the original request and does not process the new request.
The request ID must be a valid UUID and cannot be a zero UUID (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateDatasetConfigRequest
impl CreateDatasetConfigRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_dataset_config_id<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset_config_id<T: Into<String>>(self, v: T) -> Self
Sets the value of dataset_config_id.
Example
let x = CreateDatasetConfigRequest::new().set_dataset_config_id("example");Sourcepub fn set_dataset_config<T>(self, v: T) -> Selfwhere
T: Into<DatasetConfig>,
pub fn set_dataset_config<T>(self, v: T) -> Selfwhere
T: Into<DatasetConfig>,
Sets the value of dataset_config.
Example
use google_cloud_storageinsights_v1::model::DatasetConfig;
let x = CreateDatasetConfigRequest::new().set_dataset_config(DatasetConfig::default()/* use setters */);Sourcepub fn set_or_clear_dataset_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetConfig>,
pub fn set_or_clear_dataset_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<DatasetConfig>,
Sets or clears the value of dataset_config.
Example
use google_cloud_storageinsights_v1::model::DatasetConfig;
let x = CreateDatasetConfigRequest::new().set_or_clear_dataset_config(Some(DatasetConfig::default()/* use setters */));
let x = CreateDatasetConfigRequest::new().set_or_clear_dataset_config(None::<DatasetConfig>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateDatasetConfigRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateDatasetConfigRequest
impl Clone for CreateDatasetConfigRequest
Sourcefn clone(&self) -> CreateDatasetConfigRequest
fn clone(&self) -> CreateDatasetConfigRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more